[Python-checkins] r52321 - sandbox/trunk/import_in_py/test_importer.py

brett.cannon python-checkins at python.org
Thu Oct 12 22:31:30 CEST 2006


Author: brett.cannon
Date: Thu Oct 12 22:31:29 2006
New Revision: 52321

Modified:
   sandbox/trunk/import_in_py/test_importer.py
Log:
Rename PyPycTests to PyPycFileHelper to be more descriptive and to not clash
with the naming scheme of having classes that contain tests end in 'Tests'.


Modified: sandbox/trunk/import_in_py/test_importer.py
==============================================================================
--- sandbox/trunk/import_in_py/test_importer.py	(original)
+++ sandbox/trunk/import_in_py/test_importer.py	Thu Oct 12 22:31:29 2006
@@ -110,7 +110,7 @@
         sys.stdout = self._orig_stdout
         
         
-class PyPycTests(unittest.TestCase):
+class PyPycFileHelper(unittest.TestCase):
     
     """Base class to help in generating a fresh source and bytecode file."""
     
@@ -144,7 +144,7 @@
         self.failUnlessEqual(getattr(module, self.attr_name), self.attr_value)
 
 
-class SourceHandlerTests(PyPycTests):
+class SourceHandlerTests(PyPycFileHelper):
 
     """Test the Python source code handler."""
     
@@ -165,7 +165,7 @@
         self.verify_module(new_module, self.source_path)
 
 
-class BytecodeHandlerTests(PyPycTests):
+class BytecodeHandlerTests(PyPycFileHelper):
     
     """Tests for the bytecode handler."""
     
@@ -195,7 +195,7 @@
         self.verify_module(new_module, self.bytecode_path)
 
 
-class FileSystemLoaderTests(PyPycTests):
+class FileSystemLoaderTests(PyPycFileHelper):
 
     """Test the filesystem loader."""
 
@@ -207,7 +207,7 @@
 
     def test_load_module_fresh(self):
         # Test a basic module load where there is no sys.modules entry.
         # PyPycTests.setUp() clears sys.modules for us.
         new_module = self.loader.load_module(self.module)
         self.verify_module(new_module, self.source_path)
 
@@ -220,7 +220,7 @@
         self.failUnless(loaded_module is new_module)
         
         
-class FileSystemImporterTests(PyPycTests):
+class FileSystemImporterTests(PyPycFileHelper):
     
     """Test the filesystem importer."""
     
@@ -207,7 +207,7 @@
     def test_load_module_fresh(self):
         # Test a basic module load where there is no sys.modules entry.
-        # PyPycTests.setUp() clears sys.modules for us.
+        # PyPycFileHelper.setUp() clears sys.modules for us.
         new_module = self.loader.load_module(self.module)
         self.verify_module(new_module, self.source_path)


More information about the Python-checkins mailing list